@@ -50,14 +50,21 @@ sub register_session {
     my ($self,$env) = @_;
     my $session = Plack::Session->new( $env );
     my $provider_id = lc($self->provider);
+
+    $session->set( 'oauth.' . $provider_id  , 1 );
+    $session->set( 'oauth.' . $provider_id  . '.version' , $self->version );
+    $session->set( 'oauth.' . $provider_id  . '.access_token'  , $self->access_token );
+
     if( $self->version == 2 ) {
-        $session->set( 'oauth2.' . $provider_id  . '.access_token'  , $self->{params}->{access_token} );
-        $session->set( 'oauth2.' . $provider_id  . '.code'          , $self->{params}->{code} );
-        $session->set( 'oauth2.' . $provider_id  . '.token_type'    , $self->{params}->{token_type} );
-        $session->set( 'oauth2.' . $provider_id  . '.refresh_token' , $self->{params}->{refresh_token} );
+        $session->set( 'oauth.' . $provider_id  . '.code'          , $self->{params}->{code} );
+
+        $session->set( 'oauth.' . $provider_id  . '.token_type'    , $self->{params}->{token_type} )
+                    if $self->params->{token_type};
+
+        $session->set( 'oauth.' . $provider_id  . '.refresh_token' , $self->{params}->{refresh_token} ) 
+                    if $self->params->{refresh_token};
     } 
     elsif( $self->version == 1 ) {
-        $session->set( 'oauth.' . $provider_id . '.access_token' , $self->{params}->{access_token} );
         $session->set( 'oauth.' . $provider_id . '.access_token_secret' , $self->{params}->{access_token_secret} );
     }
 }
